VER = 1.2
STAGE = ("alpha", 1)

VERSION = f"v{VER}-{STAGE[0]}-{STAGE[1]}" #Full version string.

PACKAGE_NAME = f"NovaUniverse.py ({VERSION}) (Made By Dev Goldy) \n"

FOOTER = "\nCopyright (c) 2022-present (Dev Goldy)"